%%
%% This is file `iet-ell.cls' based on ``article.cls'', a LaTeX class for manuscripts submitted to the
%%% The Institution of Engineering and Technology
%% Copyright (c) 2021 The Institution of Engineering and Technology

%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.

%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{iet-ell}[2021/03/05 v1.0
 Standard LaTeX document class of Electronic Letters (IET Society)]
\def\@classname{iet-ell}
\RequirePackage{xkeyval}

\define@choicekey*+{iet-ell.cls}{format}[\ELL@format\ELL@format@nr]{2col, 1col}[2col]{}{\ClassError{\@classname}{The option format must be 2col or 1col}}
\ExecuteOptionsX{format}

\newif\if@maketitle@occur%

\ProcessOptionsX

\ifcase\ELL@format@nr%
  \LoadClass[twoside,fleqn,twocolumn]{article}%
\or%
  \LoadClass[twoside,fleqn,onecolumn]{article}%
\fi%
\usepackage[T1]{fontenc}
\RequirePackage{latexsym,balance}
%% \RequirePackage[intlimits,sumlimits,namelimits,centertags]{amsmath}%
\RequirePackage{booktabs}
\RequirePackage{totpages}
\usepackage[figuresright]{rotating}
\RequirePackage{amsthm}
\RequirePackage{times}
\RequirePackage{newtxmath}
%
\RequirePackage[numbers,square,sort&compress]{natbib}
\renewcommand\@biblabel[1]{#1.\hskip3pt}
\setcitestyle{numbers,square}
\def\withinref{no}%
\renewenvironment{thebibliography}[1]
     {\gdef\withinref{yes}%
       \section{\refname}\fontsize{8}{10}\selectfont%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist\gdef\withinref{no}}

\RequirePackage[bookmarks=false,unicode,hidelinks]{hyperref}
\pdfstringdefDisableCommands{%
  \def\addtocounter#1#2{}%
  \def\unskip{}%
  \def\textbullet{- }%
  \def\textrightarrow{ -> }%
  \def\footnotemark{}%
}
\urlstyle{rm}
\def\do@url@hyp{\do\-}%

\RequirePackage{graphicx,stfloats}
\graphicspath{{art/}}

\setlength\paperwidth{8.27in}%
\setlength\paperheight{11.69in}%
\RequirePackage{geometry}
  \geometry{twoside=true,%showcrop,showframe,
    paperwidth=8.27in,
    paperheight=11.69in,
    textheight=745.5pt,
    textwidth=42.5pc,
    columnsep=22pt,
    lmargin=35.2pt,
    top=35pt,
    headheight=0pt,
    headsep=0pt,
    footskip=24pt,
  }

\def\@journalName{ELECTRONICS LETTERS}%
\def\@journalUrl{wileyonlinelibrary.com/iet-el}%
\def\@JournalDOI{\url{https://doi.org/\@articledoi}}%
\def\ietcopyright{published by John Wiley \& Sons Ltd on behalf of The Institution of Engineering and Technology}%
\def\@copyrighttext{The Institution of Engineering and Technology}%
%
\let\@subtitle\empty%
\def\subtitle#1{\gdef\@subtitle{#1}}
\def\setcopyright#1{\gdef\@setcopyright{#1}}\setcopyright{}%

\renewcommand\normalsize{%
   \@setfontsize\normalsize{8.5}{10.5}%
   \abovedisplayskip 6.5\p@ \@plus2\p@ \@minus5\p@
   \abovedisplayshortskip \z@ \@plus3\p@
   \belowdisplayshortskip 6\p@ \@plus3\p@ \@minus3\p@
   \belowdisplayskip \abovedisplayskip
   \let\@listi\@listI}

\renewcommand\footnotesize{%
   \@setfontsize\footnotesize{7}{9}%
   \abovedisplayskip 6\p@ \@plus2\p@ \@minus4\p@
   \abovedisplayshortskip \z@ \@plus\p@
   \belowdisplayshortskip 3\p@ \@plus\p@ \@minus2\p@
   \def\@listi{\leftmargin\leftmargini
               \topsep 3\p@ \@plus\p@ \@minus\p@
               \parsep 2\p@ \@plus\p@ \@minus\p@
               \itemsep \parsep}%
   \belowdisplayskip \abovedisplayskip
}

\renewcommand\small{%
   \@setfontsize\small{7}{8}%
   \abovedisplayskip 6.5\p@ \@plus3\p@ \@minus4\p@
   \abovedisplayshortskip \z@ \@plus2\p@
   \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
   \def\@listi{\leftmargin\leftmargini
               \topsep 4\p@ \@plus2\p@ \@minus2\p@
               \parsep 2\p@ \@plus\p@ \@minus\p@
               \itemsep \parsep}%
   \belowdisplayskip \abovedisplayskip
}

\renewcommand\scriptsize{\@setfontsize\scriptsize\@ixpt\@ixpt}
\renewcommand\tiny{\@setfontsize\tiny\@vpt\@vipt}
\renewcommand\large{\@setfontsize\large{12}{14}}
\renewcommand\Large{\@setfontsize\Large{16}{18}}
\renewcommand\LARGE{\@setfontsize\LARGE\@xviipt{22}}

%%%%%%%%%%%%%%%% Defined commands %%%%%%%%%%
\def\jname#1{\gdef\@jname{#1}}\let\@jname\empty%
\def\ietVolume#1{\gdef\@jvol{#1}}\let\@jvol\empty
\def\ietYear#1{\gdef\@jyear{#1}}\let\@jyear\empty
\def\ietDoi#1{\gdef\@articledoi{10.1049/#1}}\let\@articledoi\empty
\def\received#1{\gdef\@received{#1}}\let\@received\empty
\def\revised#1{\gdef\@revised{#1}}\let\@revised\empty
\def\accepted#1{\gdef\@accepted{#1}}\let\@accepted\empty
\def\dochead#1{\gdef\@dochead{\uppercase{\spreadout{#1}}}}\let\@dochead\empty

\def\@seccntformat#1{\csname the#1\endcsname}%

\def\@startsection#1#2#3#4#5#6{%
  \if@noskipsec \leavevmode \fi
  \par
  \@tempskipa #4\relax
  \@afterindenttrue
  \ifdim \@tempskipa <\z@
    \@tempskipa -\@tempskipa \@afterindentfalse
  \fi
  \if@nobreak
    \everypar{}%
  \else
    \addpenalty\@secpenalty\addvspace\@tempskipa
  \fi
  \@ifstar
    {\@ssect{#3}{#4}{#5}{#6}}%
    {\@dblarg{\@sect{#1}{#2}{#3}{#4}{#5}{#6}}}}

\def\@sect#1#2#3#4#5#6[#7]#8{%
  \edef\@toclevel{\ifnum#2=\@m 0\else\number#2\fi}%
  \ifnum #2>\c@secnumdepth
    \let\@svsec\@empty
  \else
    \refstepcounter{#1}%
    \protected@edef\@svsec{\@seccntformat{#1}\relax}%
  \fi
  \@tempskipa #5\relax
  \ifdim \@tempskipa>\z@
    \begingroup #6\relax
     \ifnum#2=1%
        {{\hskip #3\relax\@svsec}%
          \interlinepenalty \@M\ifx\withinref\YES\hspace*{-10pt}\fi#8\@@par}%
     \else%
        {{\hskip #3\relax\@svsec}%
          \interlinepenalty \@M#8\@@par}%
     \fi%
    \endgroup
    \csname #1mark\endcsname{#7}%
    %% \ifnum #2>\c@secnumdepth \else
    %%     \@tochangmeasure{\csname the#1\endcsname}%
    %% \fi
    \addcontentsline{toc}{#1}{%
      \ifnum #2>\c@secnumdepth \else
        \protect\numberline{\csname the#1\endcsname}%
      \fi
      #7}%
  \else
    \def\@svsechd{%
      #6{\hskip #3\relax
      \@svsec #8:}%
      \csname #1mark\endcsname{#7}%
      %% \ifnum #2>\c@secnumdepth \else
      %%   \@tochangmeasure{\csname the#1\endcsname\space}%
      %% \fi
      \addcontentsline{toc}{#1}{%
        \ifnum #2>\c@secnumdepth \else
          \protect\numberline{\csname the#1\endcsname}%
        \fi
        #7}}%
  \fi
  \@xsect{#5}}

\def\@xsect#1{%
  \@tempskipa #1\relax
  \ifdim \@tempskipa>\z@
    \par \nobreak
    \vskip \@tempskipa
    \@afterheading
  \else
    \@nobreakfalse
    \global\@noskipsectrue
    \everypar{%
      \if@noskipsec
        \global\@noskipsecfalse
       {\setbox\z@\lastbox}%
        \clubpenalty\@M
        \begingroup \@svsechd \endgroup
        \unskip
        \@tempskipa #1\relax
        \hskip -\@tempskipa
      \else
        \clubpenalty \@clubpenalty
        \everypar{}%
      \fi}%
  \fi
  \ignorespaces}

\def\@ssect#1#2#3#4#5{\phantomsection%
  \@tempskipa #3\relax
  \ifdim \@tempskipa>\z@
    \begingroup
      #4{%
        {\hskip #1}%
          \interlinepenalty \@M #5\@@par}%
    \endgroup
    \addcontentsline{toc}{section}{#5}
  \else
    \def\@svsechd{#4{\hskip #1\relax #5}}%
  \fi
  \@xsect{#3}}

\setlength\parindent{10pt}
\setlength\parskip{0\p@}%

\def\spreadoutfactor{1.2}
%
\def\spreadout#1{%
  \gdef\temp{#1}\dimen0 = \spreadoutfactor pt
  \expandafter\dospreadout\temp\endmark\kern-\dimen0}
%
\def\dospreadout{%
  \afterassignment\findospreadout
  \let\next= }
%
\def\findospreadout{%
   \ifx\next\endmark
      \let\nextaction = \relax
   \else
      \let\nextaction = \dospreadout
      \next
      \kern\dimen0
   \fi
   \nextaction}

\def\@fnsymbol#1{%
   \ifcase#1\or *\or
   \ensuremath{\dagger}\or
   \ensuremath{\ddagger} \or
   \ensuremath{\mathsection}\or
   \ensuremath{\mathparagraph}\or
   \|\or
   {**}\or
   \ensuremath{\dagger\dagger}\or
   \ensuremath{\ddagger\ddagger}\else
   \@ctrerr \fi
}%

\def\titlefont{\fontfamily{\sfdefault}\fontsize{11.5}{13.5}\fontseries{b}\selectfont\raggedright\mathversion{bold}}
\def\subtitlefont{}
\def\authorfont{\fontsize{10}{12}\selectfont\raggedright}%
\def\affilfont{\itshape\raggedright}%
\def\abstractfont{\fontsize{7.5}{9.5}\selectfont}
\def\keywordfont{\fontsize{10}{12}\selectfont}
\def\rffont{\fontfamily{\sfdefault}\fontsize{10.5}{10.5}\selectfont}
%
\def\sectionfont{\ifx\withinref\YES\relax\bfseries\else\itshape\fi}
\def\subsectionfont{\sectionfont}
\def\subsubsectionfont{\sectionfont}%
\def\paragraphfont{}%
\def\subparagraphfont{}%
\def\tablefont{\fontsize{7}{13}\selectfont}%
\def\tableheadfont{\fontsize{7}{9}\selectfont}
\def\tabnotefont{\reset@font\fontsize{7}{9}}%

\gdef\YES{yes}
\gdef\NO{no}

\def\ps@plain{\overfullrule0pt%
    \let\@mkboth\@gobbletwo%
    \def\@oddfoot{\hb@xt@\textwidth{\rffont{\itshape\@journalName\enspace\@journalUrl}\hfill\thepage}}%
    \let\@evenfoot\@oddfoot%
    \def\@evenhead{}%
    \let\@oddhead\@evenhead%
}

\def\authorsep{,}

\let\ietaffil\empty
\let\ietauthors\empty
\let\sep\@empty
\let\@author@crosrefs\empty
\newcount\authorcount%
\newcount\tempcount%
\newcount\totaucount%
\def\author{\@ifnextchar[{\@@author}{\@author}}

\def\@@author[#1]#2{%
     \global\advance\authorcount\@ne%
     \expandafter\protected@xdef\csname author@name\romannumeral\the\authorcount\endcsname{#2}%
     \expandafter\protected@xdef\csname author@refs\romannumeral\the\authorcount\endcsname{#1}%
     \gdef\@author@crosrefs{#1}%
}

\def\@author#1{%
     \global\advance\authorcount\@ne%
     \expandafter\protected@xdef\csname author@name\romannumeral\the\authorcount\endcsname{#1}%
}
\def\orcid#1{\expandafter\protected@xdef\csname author@orcid\romannumeral\the\authorcount\endcsname{#1}}%

\gdef\checkfirst@aff{no}%
\gdef\@author@email{}%
\def\email#1{%
  \gdef\checkfirst@aff{yes}%
  \ifx\@author@crosrefs\empty%
    \protected@xdef\@author@email{\ifx\@author@email\@empty\else\@author@email, \fi#1}%
  \else%
    \protected@xdef\@author@email{\ifx\@author@email\@empty\else\@author@email, \fi#1}%
    \@for\author@email:=\@author@crosrefs\do{%
      \ifx\checkfirst@aff\YES%
        \gdef\checkfirst@aff{no}%
        \@ifundefined{email@@\author@email @}{%
         \expandafter\protected@xdef\csname email@@\author@email @\endcsname{#1}}{%
         \expandafter\protected@xdef\csname email@@\author@email @\endcsname{\csname email@@\author@email @\endcsname, #1}}%
      \fi%
      }%
  \fi%
}%

\def\ietauthors{%
  \ifnum\authorcount>\z@%
    \tempcount=\z@%
    \totaucount=\authorcount%
    \loop\authorfont%
      \ifnum\totaucount>\z@%
       \advance\tempcount\@ne%
       \advance\totaucount\m@ne%
       \@ifundefined{author@name\romannumeral\the\tempcount}{}{\csname author@name\romannumeral\the\tempcount\endcsname}%
        \ifnum\totaucount>\@ne\authorsep\else%
         \ifnum\authorcount=\tw@\else\ifnum\totaucount=\@ne\authorsep\fi\fi%
        \fi%
       %\ifnum\totaucount>\@ne\authorsep\fi%
       \@ifundefined{author@refs\romannumeral\the\tempcount}%
                    {\@ifundefined{author@orcid\romannumeral\the\tempcount}{}{\href{https://orcid.org/\csname author@orcid\romannumeral\the\tempcount\endcsname}{\includegraphics{orcid-logo}}}}%
                    {\edef\author@@refs{\csname author@refs\romannumeral\the\tempcount\endcsname}%
                        \@for\@@addmark:=\author@@refs\do{%
                          \textsuperscript{\unskip\sep\ref{\@@addmark}}\let\sep=,}%
                        \let\sep\empty%
                        \@ifundefined{author@orcid\romannumeral\the\tempcount}{}{\href{https://orcid.org/\csname author@orcid\romannumeral\the\tempcount\endcsname}{\includegraphics{orcid-logo}}}}%
      \ifnum\totaucount>\@ne\space\else%
        \ifnum\totaucount=\@ne\ and\ \fi%
      \fi%
    \repeat%
  \fi%
}

\def\ietaffil{}
\def\affil{\@ifnextchar[{\@@affil}{\@affil}}
\newcounter{affn}
\renewcommand\theaffn{\arabic{affn}}

\long\def\@@affil[#1]#2{\g@addto@macro\ietaffil{\normalsize\affilfont%
     \refstepcounter{affn}%
     \xdef\@currentlabel{\theaffn}%
     \label{#1}%
     \textsuperscript{\rm\theaffn}#2\@ifundefined{email@@#1@}{}{\space(E-mail:~\csname email@@#1@\endcsname)}\par}}

\long\def\@affil#1{\g@addto@macro\ietaffil{\normalsize\affilfont%
    #1\ifx\@author@email\@empty\else\space(E-mail:~\@author@email)\fi\par}}%

\newcounter{cornote}
\renewcommand\thecornote{\alph{cornote})}
\def\corresp{\@ifnextchar[{\@@corresp}{\@corresp}}

\def\@@corresp[#1]#2{\g@addto@macro\ietaffil{\reset@font%
    \refstepcounter{cornote}%
    \ifnum\c@cornote=\@ne\par\fi%
    \xdef\@currentlabel{\thecornote}%
    \label{#1}%
    \textsuperscript{\thecornote}#2\par}}

\def\@corresp#1{\g@addto@macro\ietaffil{\reset@font%
    \refstepcounter{cornote}%
    \ifnum\c@cornote=\@ne\par\fi%
    #1\par}}

\newcounter{aunote}
\renewcommand\theaunote{\@fnsymbol{\c@aunote}}
\def\authornote{\@ifnextchar[{\@@authornote}{\@authornote}}

\def\@@authornote[#1]#2{\g@addto@macro\ietaffil{\reset@font%
    \refstepcounter{aunote}%
    \ifnum\c@aunote=\@ne\par\fi%
    \protected@xdef\@currentlabel{\theaunote}%
    \label{#1}%
    {\theaunote}#2\par}}

\def\@authornote#1{\g@addto@macro\ietaffil{\reset@font%
    \stepcounter{aunote}%
    \ifnum\c@aunote=\@ne\par\fi%
    #1\par}}

%%%%%%%%%%%%%==============================================
\def\ps@headings{%
    \let\@oddfoot\@empty\let\@evenfoot\@empty
    \def\@evenhead{}%
    \def\@oddhead{}%
    \let\@mkboth\markboth
  \def\sectionmark##1{%
    \markboth {\MakeUppercase{%
      \ifnum \c@secnumdepth >\z@
        \thesection\quad
      \fi
      ##1}}{}}%
  \def\subsectionmark##1{%
    \markright {%
      \ifnum \c@secnumdepth >\@ne
        \thesubsection\quad
      \fi
      ##1}}
}

\def\ps@myheadings{\overfullrule0pt%
  \def\@evenhead{}%
  \def\@oddhead{}%
    \def\@evenfoot{\hb@xt@\textwidth{\rffont\thepage\hfill{\itshape\@journalName\enspace\@journalUrl}}}%
    \def\@oddfoot{\hb@xt@\textwidth{\rffont{\itshape\@journalName\enspace\@journalUrl}\hfill\thepage}}%
    \let\@mkboth\markboth
    \def\chaptermark##1{\markright{##1}}%{##1}}%
%    \def\chaptermark##1{\markboth{##1}{##1}}%
%    \def\sectionmark##1{\markright{##1}}
}

\renewcommand\maketitle{\par%
  \begingroup%
    \global\@maketitle@occurtrue%
    %% \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    %% \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    %% \long\def\@makefntext##1{\noindent\hb@xt@1.8em{\hss\@textsuperscript{\normalfont\@thefnmark}}##1==}%
     \global\@topnum\z@   % Prevents figures from going at top of page.
     %\twocolumn[]%
     \@maketitle%
  \endgroup
  \setcounter{footnote}{0}%
  \@afterheading\@afterindentfalse
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}
\def\@maketitle{\newpage%
  \null%
  \bgroup%
  \parindent0pt\vspace*{-10pt}%
  \let\footnote\thanks
  \thispagestyle{plain}%
  {\titlefont\@title\par\vskip10pt}%
  {\ietauthors\par}%
  {\ietaffil\par}%
  \ifvoid\absbox\else\vskip25pt{\unvbox\absbox\par}\fi%
 \addvspace{15pt plus.2pt}%
\egroup}

\setlength{\skip\footins}{20\p@ \@plus 8\p@ \@minus 8\p@}% change + based on FN font height

\setcounter{secnumdepth}{0}
\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {-11pt \@plus -.2pt \@minus -.2pt}%
                                   {\ifx\withinref\YES3pt\else-.5em\fi}%
                                   {\sectionfont}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-11pt \@plus -.2pt \@minus -.2pt}%
                                     {-.5em}%
                                     {\subsectionfont}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-11pt \@plus -.2pt \@minus -.2pt}%
                                     {-.5em}%
                                     {\subsubsectionfont}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                    {-12pt}%
                                    {0.0001pt}%
                                    {\paragraphfont}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
                                       {-12pt}%
                                       {-.5em}%
                                      {\subparagraphfont}}
\newbox\absbox
\renewenvironment{abstract}{%
  \if@maketitle@occur\ClassError{\@classname}{Abstract must be defined before maketitle command. Please move it!}\fi%
  \global\setbox\absbox\vbox\bgroup\par\abstractfont\leftskip31pt\noindent%
  }%
  {\par\egroup}

\let\@keywords\empty%
\long\def\keywords#1{\gdef\@keywords{\keywordfont#1}}

\newenvironment{extract}{\par\addvspace{6pt plus2pt}%
      \parindent0pt\fontsize{10}12{}\selectfont\ignorespaces% 
}{%
      \par\addvspace{6pt plus2pt}}

\let\quotation\extract
\let\endquotation\endextract

\newcommand\acksname{Acknowledgments}
\newenvironment{acks}{%
  \section{\acksname}%
}{\par\Printcopyright}

\def\Printcopyright{\parindent\z@\vskip10pt%
  \copyright\space\the\year\space The Authors.\space\textit{Electronics Letters}\space\ietcopyright\par\vskip3pt%
  \ifthenelse{\equal{\@setcopyright}{open}}{This is an open access article under the terms of the Creative Commons Attribution License, which permits use, distribution and reproduction in any medium, provided the original work is properly cited.\par}{}%
  \ifx\@received\@empty\else\textit{Received:\space}\@received\fi\ifx\@accepted\@empty\else\ifx\@received\@empty\else\quad\fi\textit{Accepted:\space}\@accepted\fi%
  \ifx\@articledoi\@empty\else\par{doi:\space\@articledoi}\fi%
}

\RequirePackage{caption,float}
\DeclareCaptionLabelSeparator{myspace}{\hskip.5em}
\DeclareCaptionFont{figfont}{\fontsize{8}{10}\selectfont\itshape}
\DeclareCaptionFont{tabfont}{\fontsize{9}{11}\selectfont\itshape}
\captionsetup[figure]{labelformat=simple, labelsep=myspace, textfont=figfont, singlelinecheck=false, skip=10pt, labelfont=bf}
\captionsetup[table]{position=top, labelformat=simple, labelsep=period, font=tabfont, singlelinecheck=false, skip=2pt}
\renewcommand\figurename{Fig}%%

\renewcommand\footnoterule{%
  \kern-3\p@
  {\hrule\@width\hsize}
  \kern2.6\p@}
\renewcommand\@makefntext[1]{\leavevmode{\@makefnmark\hskip1pt}#1}

\renewcommand\theenumii{\@arabic\c@enumii}
\renewcommand\labelitemii{\textbullet}
\def\labelenumi{\theenumi.}
\def\labelenumii{\theenumii.}
\def\labelenumiii{\theenumiii.}
\def\labelenumiv{\theenumiv.}

\AtBeginDocument{%
  \setlength\labelsep{5pt}
  \setlength\leftmargini{\z@}
  \addtolength\leftmargini{2.8\labelsep}
  %% Second-level and higher lists.
  \setlength\leftmarginii{\leftmargini}
  \addtolength\leftmarginii{.25\labelsep}
  
  \def\@listi{\leftmargin\leftmargini
            \parsep 0\p@% \@plus2\p@ \@minus\p@
            \topsep 9\p@% \@plus2\p@% \@minus2\p@
            \itemsep0pt}%
  \def\@listii {\leftmargin\leftmarginii
              \labelwidth\leftmarginii
              \advance\labelwidth-\labelsep
              \topsep 0\p@% \@plus2\p@ \@minus\p@
              \parsep 0\p@% \@plus\p@  \@minus\p@
              \itemsep0pt}
  \def\@listiii{\leftmargin\leftmarginiii
              \labelwidth\leftmarginiii
              \advance\labelwidth-\labelsep
              \topsep  2\p@ \@plus\p@\@minus\p@
              \parsep  \z@
              \partopsep \p@ \@plus\z@ \@minus\p@
              \itemsep \topsep}
}% \@plus2\p@ \@minus\p@}

\newenvironment{unnumlist}{%%%
    \list{}{%
%    \listparindent18pt\raggedright
        \leftmargin12pt
        \itemindent-6pt
    \parsep0pt
    \itemsep0pt
    \partopsep0pt}
    \def\makelable##1{##1}%
}{%%
    \endlist
}%

\newtheorem{theorem}{Theorem}
\newtheorem{lemma}{Lemma}
\newtheorem{corollary}{Corollary}

\theoremstyle{definition}
\newtheorem{example}{Example}
\newtheorem{definition}{Definition}
\newtheorem{assumption}{Assumption}

\theoremstyle{remark}
\newtheorem{remark}{Remark}

\def\thm@space@setup{%
  \thm@preskip=\baselineskip%
  \thm@postskip=\thm@preskip%
}

\newcounter{tabnotecount}[table]%
\renewcommand\thetabnotecount{\alph{tabnotecount}}%

\def\tabular{\tablefont\def\@halignto{}\@tabular}
\@namedef{tabular*}#1{\tablefont%
 \setlength\dimen@{#1}%
   \edef\@halignto{to\the\dimen@}\@tabular}

\def\brk{\\[-4pt]}
\newcommand\tch[4]{\multicolumn{#1}{#2}%
   {\tableheadfont\begin{tabular}[#3]{@{}#2@{}}%
    \ignorespaces#4\unskip
    \end{tabular}}}

\def\tablenote{\@ifnextchar[{\@@tablenote}{\@tablenote}}
\def\@tablenote#1{{\tabnotefont\par\vskip1pt{\tabnotefont#1\par}}}%
\def\@@tablenote[#1]#2{\par\vskip1pt%
    \refstepcounter{tabnotecount}%
    \xdef\@currentlabel{\thetabnotecount}%
    \label{#1}%
    {\tabnotefont\textsuperscript{\thetabnotecount\hskip2pt}{\tabnotefont#2\par}}%
}

\def\tabnotesep{,}%
\def\print@tabnote#1,#2\@nil{%
  \def\@tmp{#2}%
  \ifx\@tmp\@empty%
    \textsuperscript{{\ref{#1}}}%
  \else%
    \textsuperscript{{\ref{#1}}\tabnotesep}%
    \expandafter\print@tabnote#2\@nil%
  \fi%
}

\def\tabnoteref#1{\expandafter\print@tabnote#1,\@nil}

\newenvironment{tabnote}{\par\vskip2pt}{\par}%

\def\hline{%
  \noalign{\ifnum0=`}\fi\vskip1.5pt
      \hrule \@height \arrayrulewidth\vskip1.5pt
      \futurelet \reserved@a\@xhline}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Page break penalties
\@lowpenalty   51
\@medpenalty  151
\@highpenalty 301

% Disable page breaks before equations, allow pagebreaks after
% equations and discourage widow lines before equations.
\displaywidowpenalty 100
\predisplaypenalty   10000
\postdisplaypenalty  0

% Allow loose lines rather than overfull lines
\vbadness=9999%
\tolerance=9999%

% The maximum number of floats at the top and bottom of a page.
\setcounter{topnumber}{3}%
\setcounter{bottomnumber}{3}%

% The maximum part of the top or bottom of a text page that can be
% occupied by floats. This is set so that at least four lines of text
% fit on the page.
\renewcommand\topfraction{.921}%
\renewcommand\bottomfraction{.921}%

% The minimum amount of a text page that must be occupied by text.
% This should accomodate four lines of text.
%%\renewcommand\textfraction{.13}%
\renewcommand\textfraction{.1}%

% The minimum amount of a float page that must be occupied by floats.
%%\renewcommand\floatpagefraction{.887}%
\renewcommand\floatpagefraction{.95}%

% The same parameters repeated for double column output
%%\renewcommand\dbltopfraction{.88}%
%%\renewcommand\dblfloatpagefraction{.88}%
\renewcommand\dbltopfraction{.95}%
\renewcommand\dblfloatpagefraction{.95}%

% Hyphenation; don't split words into less than three characters
\lefthyphenmin=3
\righthyphenmin=3

\pagestyle{myheadings}
\pagenumbering{arabic}
\sloppy
\frenchspacing
\endinput
%%
%% End of file `article.cls'.
